package cz.muni.fi.pa165.model;

import org.hibernate.validator.constraints.NotBlank;

import javax.validation.constraints.Min;
import javax.validation.constraints.NotNull;
import javax.validation.constraints.Pattern;
import javax.validation.constraints.Size;

/**
 * JavaBean for book. Values are checked by JSR-303 "Bean Validation" implementation Hibernate Validator.
 */
public class Book {

    private int id;

    @NotNull
    @Pattern(regexp = "[A-Z].*")
    @Size(min = 1, max = 30)
    private String author; //field-level validation

    @NotBlank
    @Size(min = 1, max = 30)
    private String name;

    @Min(1)
    private int price;

    private boolean paperback;

    //enum type for book colors
    public enum Color {
        GREEN, BLUE, RED, ORANGE, WHITE, OTHER
    }

    private Color color;

    public Book() {
    }

    public Book(int id, String author, String name, int price, boolean paperback, Color color) {
        this.id = id;
        this.author = author;
        this.name = name;
        this.price = price;
        this.paperback = paperback;
        this.color = color;
    }

    public int getId() {
        return id;
    }

    public void setId(int id) {
        this.id = id;
    }

    public String getAuthor() {
        return author;
    }

    public void setAuthor(String author) {
        this.author = author;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public Color getColor() {
        return color;
    }

    public void setColor(Color color) {
        this.color = color;
    }

    public int getPrice() {
        return price;
    }

    public void setPrice(int price) {
        this.price = price;
    }

    public boolean isPaperback() {
        return paperback;
    }

    public void setPaperback(boolean paperback) {
        this.paperback = paperback;
    }

    @Override
    public String toString() {
        return "Book{" +
                "id=" + id +
                ", author='" + author + '\'' +
                ", name='" + name + '\'' +
                ", paperback=" + paperback +
                ", color=" + color +
                ", price=" + price +
                '}';
    }
}
