package cz.muni.fi.pa165.web;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.web.filter.OncePerRequestFilter;

import javax.servlet.FilterChain;
import javax.servlet.ServletException;
import javax.servlet.annotation.WebFilter;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;

/**
 * Allows CORS (Cross-Origin Resource Sharing). http://www.w3.org/TR/cors/
 */
@WebFilter(urlPatterns = "/mvc/book/*")
public class CorsFilter extends OncePerRequestFilter {

    final static Logger log = LoggerFactory.getLogger(CorsFilter.class);

    @Override
    protected void doFilterInternal(HttpServletRequest request, HttpServletResponse response, FilterChain filterChain)
            throws ServletException, IOException {
        String origin = request.getHeader("Origin");
        if (origin != null) {
            response.addHeader("Access-Control-Allow-Origin", origin);
            response.addHeader("Vary", "Origin");
            String acrm = request.getHeader("Access-Control-Request-Method");
            if (acrm != null && "OPTIONS".equals(request.getMethod())) {
                log.debug("CORS pre-flight request from {} to allow {} {}", origin, acrm, request.getRequestURI());
                response.addHeader("Access-Control-Allow-Methods", acrm);
                response.addHeader("Access-Control-Allow-Headers", "Content-Type");
                response.addHeader("Access-Control-Max-Age", "3600");
            }
        }
        filterChain.doFilter(request, response);
    }
}


